import django.db.models.deletion
from django.db import migrations, models


def move_timeslot_data_to_episode(apps, schema_editor):
    TimeSlot = apps.get_model("program", "TimeSlot")
    for timeslot in TimeSlot.objects.filter(episode__isnull=False).select_related("episode"):
        episode = timeslot.episode
        episode.memo = timeslot.memo
        episode.media_id = timeslot.playlist_id
        episode.save()


def move_episode_data_to_timeslot(apps, schema_editor):
    TimeSlot = apps.get_model("program", "TimeSlot")
    for timeslot in TimeSlot.objects.filter(episode__isnull=False).select_related("episode"):
        timeslot.memo = timeslot.episode.memo
        timeslot.playlist_id = timeslot.episode.media_id
        timeslot.save()


class Migration(migrations.Migration):
    dependencies = [
        ("program", "0127_alter_playlistentry_options_and_more"),
    ]

    operations = [
        migrations.RenameModel("Note", "Episode"),
        migrations.RenameField(
            model_name="episode",
            old_name="language",
            new_name="languages",
        ),
        migrations.RenameField(
            model_name="episode",
            old_name="topic",
            new_name="topics",
        ),
        # Move playlist and memo from timeslot to episode.
        migrations.AddField(
            model_name="episode",
            name="media",
            field=models.ForeignKey(
                blank=True,
                help_text="Media for this episode.",
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to="program.playlist",
            ),
        ),
        migrations.AddField(
            model_name="episode",
            name="memo",
            field=models.TextField(blank=True, help_text="Memo for this episode."),
        ),
        migrations.RunPython(
            move_timeslot_data_to_episode,
            move_episode_data_to_timeslot,
        ),
        migrations.RemoveField(
            model_name="timeslot",
            name="memo",
        ),
        migrations.RemoveField(
            model_name="timeslot",
            name="playlist",
        ),
    ]
