import pytest

from program.tests.factories import LicenseFactory

pytestmark = pytest.mark.django_db


def url(license=None):
    return f"/api/v1/licenses/{license.id}/" if license else "/api/v1/licenses/"


def test_create_license(admin_api_client):
    data = {"identifier": "IDENTIFIER", "name": "NAME"}

    response = admin_api_client.post(url(), data)

    assert response.status_code == 201

    assert response.data["identifier"] == data["identifier"]
    assert response.data["name"] == data["name"]


def test_retrieve_license(common_api_client1, license_):
    response = common_api_client1.get(url(license=license_))

    assert response.status_code == 200

    assert response.data["identifier"] == license_.identifier
    assert response.data["name"] == license_.name


def test_delete_license(admin_api_client, license_):
    response = admin_api_client.delete(url(license=license_))

    assert response.status_code == 204


def test_list_licenses(common_api_client1):
    LICENSES = 3
    LicenseFactory.create_batch(size=LICENSES)

    response = common_api_client1.get(url())

    assert response.status_code == 200
    assert len(response.data) == LICENSES


def test_update_identifier(admin_api_client, license_):
    update = {
        "identifier": "IDENTIFIER",
    }

    response = admin_api_client.patch(url(license=license_), update)

    assert response.status_code == 200

    assert response.data["identifier"] == update["identifier"]


def test_update_name(admin_api_client, license_):
    update = {
        "name": "NAME",
    }

    response = admin_api_client.patch(url(license=license_), update)

    assert response.status_code == 200

    assert response.data["name"] == update["name"]


def test_update_needs_autor(admin_api_client, license_):
    update = {"needs_author": False}

    response = admin_api_client.patch(url(license=license_), update)

    assert response.status_code == 200

    assert response.data["needs_author"] == update["needs_author"]


def test_update_requires_express_permission_for_publication(admin_api_client, license_):
    update = {"requires_express_permission_for_publication": False}

    response = admin_api_client.patch(url(license=license_), update)

    assert response.status_code == 200

    assert (
        response.data["requires_express_permission_for_publication"]
        == update["requires_express_permission_for_publication"]
    )


def test_update_url(admin_api_client, license_):
    update = {"url": "https://aura.radio/"}

    response = admin_api_client.patch(url(license=license_), update)

    assert response.status_code == 200

    assert response.data["url"] == update["url"]
